@@ -8,7 +8,7 @@ from urllib.parse import quote
 import pytest
 from playwright.sync_api import BrowserContext, BrowserType, Page, expect
 
-from univention.config_registry import handler_set, handler_unset
+from univention.config_registry import handler_set, handler_unset, ucr
 from univention.testing import ucr as _ucr, udm as _udm
 from univention.testing.browser import logger
 from univention.testing.browser.generic_udm_module import UserModule
@@ -49,6 +49,7 @@ def browser_type_launch_args(browser_type_launch_args):
     return {
         **browser_type_launch_args,
         "executable_path": "/usr/bin/chromium",
+        "args": ["--remote-debugging-port=3157"],
     }
 
 
@@ -223,3 +224,9 @@ def app_center_cache():
     app_center_cache = AppCenterCacheTest()
     yield app_center_cache
     app_center_cache.restore()
+
+
+german_english_not_available = pytest.mark.skipif(
+    {locale.split(".")[0] for locale in ucr.get("locale", "").split()} < {"de_DE", "en_US"},
+    reason="German and english locale needs to be configured"
+)
