@@ -769,7 +769,7 @@ class TestCase:
                         cmd, executable=self.exe.filename,
                         shell=False, stdout=PIPE, stderr=PIPE,
                         close_fds=True, cwd=dirname,
-                        preexec_fn=os.setsid,
+                        preexec_fn=os.setsid,  # noqa: PLW1509
                     )
                     to_stdout, to_stderr = sys.stdout, sys.stderr
                 else:
@@ -778,7 +778,7 @@ class TestCase:
                             cmd, executable=self.exe.filename,
                             shell=False, stdin=devnull,
                             stdout=PIPE, stderr=PIPE, close_fds=True,
-                            cwd=dirname, preexec_fn=prepare_child,
+                            cwd=dirname, preexec_fn=prepare_child,  # noqa: PLW1509
                         )
                     to_stdout = to_stderr = result.environment.log
 
